@@ -3,7 +3,7 @@
     Functions for variable selection in each node of a tree
     *\file IndependenceTest.c
     *\author $Author: hothorn $
-    *\date $Date: 2007-01-15 11:24:41 +0100 (Mon, 15 Jan 2007) $
+    *\date $Date: 2007-02-02 11:22:45 +0100 (Fri, 02 Feb 2007) $
 */
                 
 #include "party.h"
@@ -145,7 +145,7 @@ void C_GlobalTest(const SEXP learnsample, const SEXP weights,
     dweights = REAL(weights);
     
     /* y = get_transformation(responses, 1); */
-    y = get_jointtransf(responses);
+    y = get_test_trafo(responses);
     
     expcovinf = GET_SLOT(fitmem, PL2_expcovinfSym);
     C_ExpectCovarInfluence(REAL(y), ncol(y), REAL(weights), 
